@@ -367,6 +367,13 @@ test('extraneous non-combinating whitespace', '  [href]   ,  [class]   ', (t, tr
     t.deepEqual(tree.nodes[1].nodes[0].spaces.after, '   ');
 });
 
+test('newline in attribute selector', '[class="woop \\\nwoop woop"]', (t, tree) => {
+    t.deepEqual(tree.nodes[0].nodes[0].attribute, 'class');
+    t.deepEqual(tree.nodes[0].nodes[0].operator, '=');
+    t.deepEqual(tree.nodes[0].nodes[0].value, 'woop \nwoop woop');
+    t.true(tree.nodes[0].nodes[0].quoted);
+});
+
 test('comments within attribute selectors', '[href/* wow */=/* wow */test]', (t, tree) => {
     t.deepEqual(tree.nodes[0].nodes[0].attribute, 'href');
     t.deepEqual(tree.nodes[0].nodes[0].operator, '=');
@@ -449,7 +456,7 @@ testDeprecation('deprecated constructor', '', (t) => {
         () => {
             return new Attribute({value: '"foo"', attribute: "data-bar"});
         },
-        "Constructing an Attribute selector with a value without specifying quoteMark is deprecated. Note: The value should be unescaped now."
+        {message: "Constructing an Attribute selector with a value without specifying quoteMark is deprecated. Note: The value should be unescaped now."}
     );
 });
 
@@ -459,7 +466,7 @@ testDeprecation('deprecated get of raws.unquoted ', '', (t) => {
             let attr = new Attribute({value: 'foo', quoteMark: '"', attribute: "data-bar"});
             return attr.raws.unquoted;
         },
-        "attr.raws.unquoted is deprecated. Call attr.value instead."
+        {message: "attr.raws.unquoted is deprecated. Call attr.value instead."}
     );
 });
 
@@ -469,7 +476,7 @@ testDeprecation('deprecated set of raws.unquoted ', '', (t) => {
             let attr = new Attribute({value: 'foo', quoteMark: '"', attribute: "data-bar"});
             attr.raws.unquoted = 'fooooo';
         },
-        "Setting attr.raws.unquoted is deprecated and has no effect. attr.value is unescaped by default now."
+        {message: "Setting attr.raws.unquoted is deprecated and has no effect. attr.value is unescaped by default now."}
     );
 });
 
